Module beamlit.models.agent_history
===================================

Classes
-------

`AgentHistory(created_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, agent: beamlit.types.Unset | str = <beamlit.types.Unset object>, end: beamlit.types.Unset | str = <beamlit.types.Unset object>, environment: beamlit.types.Unset | str = <beamlit.types.Unset object>, events: beamlit.types.Unset | list['AgentHistoryEvent'] = <beamlit.types.Unset object>, request_id: beamlit.types.Unset | str = <beamlit.types.Unset object>, start: beamlit.types.Unset | str = <beamlit.types.Unset object>, status: beamlit.types.Unset | str = <beamlit.types.Unset object>, took: beamlit.types.Unset | int = <beamlit.types.Unset object>, workspace: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Agent deployment history
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        agent (Union[Unset, str]): Agent name
        end (Union[Unset, str]): End time
        environment (Union[Unset, str]): Environment name
        events (Union[Unset, list['AgentHistoryEvent']]): Events
        request_id (Union[Unset, str]): Request ID
        start (Union[Unset, str]): Start time
        status (Union[Unset, str]): Status, eg: running, success, failed
        took (Union[Unset, int]): Number of milliseconds it took to complete the event
        workspace (Union[Unset, str]): The workspace the agent deployment belongs to
    
    Method generated by attrs for class AgentHistory.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `agent`
    :

    `created_at`
    :

    `end`
    :

    `environment`
    :

    `events`
    :

    `request_id`
    :

    `start`
    :

    `status`
    :

    `took`
    :

    `updated_at`
    :

    `workspace`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :